cc \
-I/usr/include/gtk-2.0 \
-I/usr/lib/gtk-2.0/include \
-I/usr/include/atk-1.0 \
-I/usr/include/cairo \
-I/usr/include/pango-1.0 \
-I/usr/include/glib-2.0 \
-I/usr/lib/glib-2.0/include \
-I/usr/include/freetype2 \
-I/usr/include/directfb \
-I/usr/include/libpng12 \
-I/usr/include/pixman-1 \
-lgtk-x11-2.0 \
-lgdk-x11-2.0 \
-latk-1.0 \
-lgdk_pixbuf-2.0 \
-lm \
-lpangocairo-1.0 \
-lpango-1.0 \
-lcairo \
-lgobject-2.0 \
-lgmodule-2.0 \
-ldl \
-lglib-2.0 \
transcoder.c -o Transcoder
