#define C_WINDOW_TITLE "Transcoder"
#define C_VIDEO_TAB_TITLE "Video"
#define C_AUDIO_TAB_TITLE "Audio"
#define C_TRAY_ICON "data/transcoder.png"
#define C_WINDOW_WIDTH 640
#define C_WINDOW_HEIGHT 480
#define C_NOTEBOOK_WIDTH 640
#define C_NOTEBOOK_HEIGHT 170
#define C_LABLE_WIDTH 100
#define C_LABLE_HEIGHT 25
#define C_ENTRY_WIDTH 60
#define C_ENTRY_HEIGHT 25

#define C_MIN_VIDEO_BITRATE 64
#define C_MAX_VIDEO_BITRATE 9808
#define C_MIN_AUDIO_BITRATE 16
#define C_MAX_AUDIO_BITRATE 1440
#define C_DEFAULT_VIDEO_BITRATE 1440
#define C_DEFAULT_AUDIO_BITRATE 128

#define C_MIN_VIDEO_WIDTH 32
#define C_MAX_VIDEO_WIDTH 6400
#define C_MIN_VIDEO_HEIGHT 32
#define C_MAX_VIDEO_HEIGHT 6400
#define C_DEFAULT_VIDEO_WIDTH 640
#define C_DEFAULT_VIDEO_HEIGHT 480

#define C_VERSION "0.0.3"
#define C_FFMPEG_PATH "./ffmpeg"

#define C_NUM_FORMATS 6
#define C_NUM_V_CODECS 7
#define C_NUM_A_CODECS 6
